@@ -10,10 +10,19 @@ Acme::Include::Data - it's easy to include data with a CPAN module
 
 =head1 DESCRIPTION
 
+This is a demonstration module which demonstrates how to include a
+data file with a Perl module and how to read it in at run time.
+
 =head1 FUNCTIONS
 
 =head2 yes_it_works
 
+This is a function for testing the module.
+
+=head1 SEE ALSO
+
+Please see L<this blog post|http://www.lemoda.net/perl/data-in-distro/> for more explanation.
+
 =head1 LICENCE
 
 You can use, redistribute, and modify this under the same licence
@@ -30,7 +39,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 
 my $data = __FILE__;
